{% load i18n %}
<p>
{% blocktrans with title=page.title %}
Page <strong>{{ title }}</strong> saved!
{% endblocktrans %}
</p>
<p>
<a href="{{ page.url }}" class="btn btn-success">{% trans "View on site" %}</a> 
<a href="{% url dashboard:page-update page.pk %}" class="btn btn-success">{% trans "Edit again" %}</a> 
</p>
