{% load i18n %}{% load url from future %}{% autoescape off %}
<p>
	{% blocktrans with name=site.name %}You're receiving this e-mail because you requested a password reset for your user account at {{ name }}.{% endblocktrans %}
</p>

<p>{% trans "Please go to the following page and choose a new password:" %}</p>
{{ reset_url }}

<p>{% trans "Thanks for using our site!" %}</p>
<p>{% blocktrans with name=site.name %}The {{ name }} team{% endblocktrans %}</p>

{% endautoescape %}
