// OSCAR ACCOUNTS UNIQUE STYLES
// -----------
.login_form, .register_form {
  form {
    .well();
  }
}
.nav-profile {
  margin-bottom:0;
}
.account-pages .content,
.account-profile .tab-content {
   padding:@baseLineHeight + 10px;
   border:1px solid darken(@grayLighter, 5%);
   border-top-width:0;
}
.nav-stacked .icon-chevron-right {
  margin-top: 5px;
  margin-right: -6px;
  .opacity(50);
}
.nav-stacked .active .icon-chevron-right {
  .opacity(100);
}
//Language select
#language_selector select {
  width:100px;
}