{% extends "layout.html" %}
{% load currency_filters %}
{% load thumbnail %}
{% load i18n %}

{% block breadcrumbs %}
<ul class="breadcrumb">
    <li>
        <a href="{% url promotions:home %}">{% trans 'Home' %}</a>
        <span class="divider">/</span>
    </li>
    <li>
        <a href="{% url customer:summary %}">{% trans 'Account' %}</a>
        <span class="divider">/</span>
    </li>
    <li class="active">{% trans 'Change password' %}</li>
</ul>
{% endblock %}

{% block title %}
{% trans 'Change password' %} | {{ block.super }}
{% endblock %}

{% block headertext %}
{% trans 'Change password' %}
{% endblock %}

{% block content %}

<form id="change_password_form" action="." method="post">
    {% csrf_token %}
    {% include 'partials/form_fields.html' with form=form %}
    <div class="form-actions">
        <button type="submit" class="btn btn-large btn-primary">{% trans 'Update password' %}</button>
        {% trans 'or' %} <a href="{% url customer:summary %}">{% trans 'cancel' %}</a>.
    </div>
</form>

{% endblock content %}
