/*** Promotional block styles ***/
.promotion_single {
  .image_container {
    min-height: 210px;
    img {
      max-height: 200px;
    }
  }
}
.sidebar {
  .promotion_single {
    h2 {
      font-size:18px;
      line-height:22px;
    }
    h3 {
      font-size:14px;
      line-height:18px;
    }
    .row-fluid {
      > [class*="span"] {
        float:none;
        width:auto;
      } 
    }
  }
}