// OSCAR CHECKOUT UNIQUE STYLES
// -----------
.basket_summary,
.later_summary {
  padding-left:0px;
  .actions {
    margin-left:0px;
  }
  .checkout-quantity {
      input {
          width: 10%;
          margin-right: 2px;
          margin-bottom:0px;
      }
  }
  .basket-products {
      border-bottom: 1px solid #E0E0E0;
      padding: 0 0 10px;
      margin-bottom: 18px;
  }
}
.basket-title {
  clear:both;
  border-bottom:1px solid lighten(@grayLight, 30%);
  padding:0 10px;
  h4 {
    margin:0;
  }
}
.basket-items {
  border-bottom:1px solid lighten(@grayLight, 30%);
  padding:10px;
  [class*="span"] {
    .image_container {
      min-height:100px;
      width:80px;
      float:left;
      margin-right:15px;
    }
    img {
      max-height:100px;
    }
  }
  &:nth-child(even) {
      background:lighten(@grayLighter, 4%);
  }
  .price_color {
    font-size:@baseFontSize + 2;
    font-weight:bold;
  }
}
#basket_totals {
	th small {
		font-weight: normal;
	}
}

.shipping_address {
  h2 {
    margin-bottom: @baseLineHeight;
  }
}
.choose-block {
  margin-top:10px;
  ul {
    .remove_bullets();
    .clearfix();
    li {
        width: @third;
        float: left;
        .default-address {
            background-color: @grayLighter;
      }
    }
  }
  .well {
    position:relative;
    form {
      position:relative;
      padding-bottom:35px;
      margin-bottom:0;
      .ship-address {
          bottom: 0;
          position: absolute;
      }
    }
    .remove-item {
      position:absolute;
      bottom: 10px;
      right: 19px;
      margin-bottom: 0;
      input {
          margin-bottom: 0;
        }
    }
  }
  .well-info.default-address {
    background-color: @successBackground;
    border-color: @successBorder;
  }
  .alert-actions {
    .clearfix();
    form,
    a {
      float:left;
      margin:0px 5px;
    }
    form {
      input {
        width:auto;
      }
    }
  } 
}

.total {
  background-color:#FDF5D9!important;
}

.checkoutNav ul li {
    background: none repeat scroll 0 0 @grayLighter;
    color: #FFFFFF;
    float: left;
    height: 30px;
    line-height: 30px;
    margin: 0;
    padding: 1px 0 4px;
    position: relative;
    text-decoration: none;
    h3 {
        text-align: center;
        font-size: 11px;
        color: @grayLight;
        margin: 0;
        margin-left: 12px;
        line-height: 30px;
    }
}

.checkoutNav ul li:after {
    border-color: transparent transparent transparent @grayLighter;
    border-style: solid;
    border-width: 14px 0 15px 15px;
    content: "";
    float: left;
    height: 0;
    position: absolute;
    right: -15px;
    top: 0;
    width: 0;
}

.checkoutNav ul li.active:after {
    border-color: transparent transparent transparent #0088CC;
}

.checkoutNav ul li.active {
    background-color: #0088CC;
}

.checkoutNav ul li:before {
    border-color: transparent transparent transparent #fff;
    border-style: solid;
    border-width: 15px 0 15px 15px;
    content: "";
    float: left;
    height: 0;
    left: 0;
    position: absolute;
    top: 0;
    width: 0;
}

.checkoutNav ul li.active h3 {
    color: #fff;
    text-align: center;
    font-size: 12px;
}
