{% extends 'dashboard/layout.html' %}
{% load currency_filters %}
{% load i18n %}

{% block body_class %}
create-page
{% endblock %}

{% block title %}
{% trans "Delete offer" %} | {% trans "Offer management" %} | {{ block.super }}
{% endblock %}

{% block breadcrumbs %}
<ul class="breadcrumb">	  	
    <li>	  	
        <a href="{% url dashboard:index %}">{% trans "Dashboard" %}</a>	  	
        <span class="divider">/</span>	  	
    </li>	  	
    <li>	  	
        <a href="{% url dashboard:offer-list %}">{% trans "Offer management" %}</a>
        <span class="divider">/</span>	  	
    </li>	 	
    <li>
        <a href="{% url dashboard:offer-detail offer.pk %}">'{{ offer.name }}'</a>
        <span class="divider">/</span>
    </li>
    <li class="active">{% trans "Delete?" %}</li>
</ul>
{% endblock %}

{% block headertext %}
{{ offer.name }}
{% endblock %}

{% block dashboard_content %}
<form action="." method="post">
	{% csrf_token %}
    <p>{% trans "Are you sure you want to delete this offer?" %}</p>
	<div class="form-actions">
		<button class="btn btn-large btn-danger" type="submit">{% trans "Delete" %}</button> or
		<a href="{% url dashboard:offer-list %}">{% trans "cancel" %}</a>
	</div>
</form>
{% endblock dashboard_content %}
