{% extends 'dashboard/layout.html' %}
{% load currency_filters %}
{% load i18n %}

{% block body_class %}
create-page
{% endblock %}

{% block title %}
{% blocktrans with name=range.name %}Delete range '{{ name }}'?{% endblocktrans %} | {% trans "Range management" %} | {{ block.super }}
{% endblock %}

{% block breadcrumbs %}
<ul class="breadcrumb">	  	
    <li>	  	
        <a href="{% url dashboard:index %}">{% trans "Dashboard" %}</a>	  	
        <span class="divider">/</span>	  	
    </li>	  	
    <li>	  	
        <a href="{% url dashboard:range-list %}">{% trans "Range management" %}</a>
        <span class="divider">/</span>	  	
    </li>	  	
    <li>
        <a href="{% url dashboard:range-update range.pk %}">'{{ range.name }}'</a>
        <span class="divider">/</span>
    </li>
    <li class="active">{% trans "Delete?" %}</li>
</ul>
{% endblock %}

{% block headertext %}
{{ range.name }}
{% endblock %}

{% block dashboard_content %}
<form action="." method="post" class="well">
    <p>{% trans "Are you sure you want to delete this range?" %}</p>
	{% csrf_token %}
	<div class="form-actions">
		<button class="btn btn-danger" type="submit">{% trans "Delete" %}</button> {% trans "or" %}
		<a href="{% url dashboard:range-list %}">{% trans "cancel" %}</a>
	</div>
</form>
{% endblock dashboard_content %}
