{% extends 'dashboard/layout.html' %}
{% block body_class %}
create-page default
{% endblock %}
{% load currency_filters %}
{% load i18n %}

{% block title %}
{{ title }} | {% trans "Vouchers" %} | {{ block.super }}
{% endblock %}

{% block breadcrumbs %}
<ul class="breadcrumb">   	
    <li> 	
        <a href="{% url dashboard:index %}">{% trans "Dashboard" %}</a>   	
        <span class="divider">/</span>   	
    </li>   	
    <li>   	
        <a href="{% url dashboard:voucher-list %}">{% trans "Vouchers" %}</a>   	
        <span class="divider">/</span>   	
    </li>   	
    <li class="active">{{ title }}</li>   	
</ul>
{% endblock %}

{% block headertext %}{{ title }}{% endblock %}

{% block dashboard_content %}
<div class="table-header">
    <h2><i class="icon-money icon-large"></i>{{ title }}</h2>
</div>
<form action="." method="post" class="well form-stacked">
	{% csrf_token %}
	{% include "partials/form_fields.html" with form=form %}
	{% block form_actions %}
	<div class="form-actions">
		<button class="btn btn-primary btn-large" type="submit">{% trans "Save" %}</button> {% trans "or" %}
		<a href="{% url dashboard:voucher-list %}">{% trans "cancel" %}</a>
	</div>
	{% endblock form_actions %}
</form>
{% endblock dashboard_content %}
