{% extends 'dashboard/reports/index.html' %}
{% load currency_filters %}
{% load i18n %}

{% block report %}
<table class="table table-striped table-bordered table-hover">
    {% if objects %}
	<tr>
		<th>{% trans "Order number" %}</th>
		<th>{% trans "User" %}</th>
		<th>{% trans "Total incl. tax" %}</th>
		<th>{% trans "Date placed" %}</th>
		<th></th>
	</tr>
	{% for order in objects %}
	<tr>
		<td>{{ order.number }}</td>
		<td>{{ order.user|default:"-" }}</td>
		<td>{{ order.total_incl_tax|currency }}</td>
		<td>{{ order.date_placed }}</td>
		<td>
			<a class="btn btn-info" href="{% url dashboard:order-detail order.number %}">{% trans "View" %}</a>
		</td>
	</tr>
	{% endfor %}
	{% else %}
    <tr><td>{% trans "No results found." %}</td></tr>
    {% endif %}
</table>
{% include "partials/pagination.html" %}
{% endblock %}
