{% extends "layout.html" %}
{% load currency_filters %}
{% load i18n %}

{% block title %}
{{ title }} | {{ block.super }}
{% endblock %}

{% block body_class %}account-pages{% endblock %}

{% block breadcrumbs %}
<ul class="breadcrumb">
    <li>
        <a href="{% url promotions:home %}">{% trans 'Home' %}</a>
        <span class="divider">/</span>
    </li>
    <li>
        <a href="{% url customer:summary %}">{% trans 'Account' %}</a>
        <span class="divider">/</span>
    </li>
    <li>
        <a href="{% url customer:address-list %}">{% trans 'Address book' %}</a>
        <span class="divider">/</span>
    </li>
    <li class="active">{{ title }}</li>
</ul>
{% endblock %}

{% block headertext %}
{% trans 'Account' %}
{% endblock %}

{% block subnavigation %}
    {% include "partials/nav_profile.html" with address_book="active" %}
{% endblock %}

{% block subheader %}
<div class="sub-header">
    <h2>{{ title }}</h2>
</div>
{% endblock subheader %}

{% block content %}
<form action="." method="post" class="form-horizontal" data-behaviours="lock">
    {% csrf_token %}
    {% include "partials/form_fields.html" with form=form %}
    <div class="form-actions">
        <button type="submit" value="Save" class="btn btn-primary btn-large">{% trans 'Save' %}</button>
        {% trans 'or' %}
        <a href="{% url customer:address-list %}">{% trans 'cancel' %}</a>
    </div>
</form>

{% endblock content %}
