{% extends 'dashboard/layout.html' %}
{% load i18n %}

{% block body_class %}create-page promotions{% endblock %}

{% block breadcrumbs %}
<ul class="breadcrumb">        	
    <li>        	
        <a href="{% url dashboard:index %}">{% trans "Dashboard" %}</a>    	  	
        <span class="divider">/</span>    	  	
    </li>    	  	
    <li>    	  	
        <a href="{% url dashboard:promotion-list %}">{% trans "Content block management" %}</a>    	  	
        <span class="divider">/</span>    	  	
    </li>    	  	
    <li class="active">{{ heading }}</li>    	  	
</ul>
{% endblock %}

{% block headertext %}
{{ heading }}
{% endblock %}

{% block dashboard_content %}

{% block promotion_form %}
<div class="table-header">
    <h2>Content block</h2>
</div>

<form action="." method="post" enctype="multipart/form-data" class="well form-stacked wysiwyg">
	{% csrf_token %}
	{% include "partials/form_fields.html" with form=form %}

    {% block inlines %} {% endblock %}

    <div class="form-actions">
        <button type="submit" class="btn btn-primary">{% trans "Save" %}</button>
		{% trans "or" %} <a href="{% url dashboard:promotion-list %}">{% trans "cancel" %}</a>
    </div>
</form>

{% endblock %}

{% if promotion %}
<table class="table table-striped table-bordered table-hover">
    <caption>{% trans "Pages displaying this content blocks" %}</caption>
    {% if links %}
	    <thead>
    		<tr>
				<th>{% trans "Page URL" %}</th>
				<th>{% trans "Position on page" %}</th>
				<th>{% trans "Actions" %}</th>
    		</tr>
    	</thead>
    	<tbody>
    		{% for link in links %}
    		<tr>
    			<td>{{ link.page_url }}</td>
    			<td>{{ link.position }}</td>
    			<td>
                    <form action="." method="post" >
    					{% csrf_token %}
    					<input type="hidden" name="action" value="remove_from_page" />
    					<input type="hidden" name="pagepromotion_id" value="{{ link.id }}" />
						<a href="{% url dashboard:promotion-list-by-url link.page_url|urlencode:"" %}" class="btn btn-info">{% trans "View all blocks on this page" %}</a>
						<button class="btn" type="submit">{% trans "Remove from page" %}</button>
    				</form>
    			</td>
    		</tr>
    		{% endfor %}
    	</tbody>
	{% else %}
	    <tr><td>{% trans "This promotion is not displayed anywhere at the moment." %}</td></tr>
    {% endif %}
</table>
<div class="table-header">
    <h3>{% trans "Add to a page" %}</h3>
</div>
<div class="well">
    <form action="." method="post" class="form-stacked">
    	{% csrf_token %}
    	<input type="hidden" name="action" value="add_to_page" />
    	{% include "partials/form_fields.html" with form=link_form %}
		<button type="submit" class="btn btn-success">{% trans "Add to page" %}</button>
    </form>
</div>
{% endif %}

{% endblock %}
