<div class="navbar primary">
    {% load flatpages %}
    {% get_flatpages '/order/' as flatpages %}
    {% if flatpages %}
    <div class="navbar-inner">
        <div class="container" style="width: auto;">
            <a class="btn btn-navbar" data-toggle="collapse" data-target=".nav-collapse">
                <span class="icon-bar"></span>
                <span class="icon-bar"></span>
                <span class="icon-bar"></span>
            </a>
            <a class="brand hidden" href="{% url promotions:home %}">{{ shop_name }}</a>
            <div class="nav-collapse">

                <ul class="nav">
                   <!-- Links to modal flatpages -->
                   {% for page in flatpages %}
                   <li>
                      <a data-toggle="modal" href="#{{ page.title|slugify }}">{{ page.title }}</a>
                   </li>
                   {% endfor %}
                   <!-- Delete this if other links present -->
                   <li><a href="/">&larr;</a></li>
                </ul>
            </div><!-- /.nav-collapse -->
        </div>
    </div><!-- /navbar-inner -->
    {% endif %}
</div><!-- /navbar -->