{% extends 'dashboard/offers/step_form.html' %}
{% load i18n %}

{% block summary %}
    {% include 'dashboard/offers/summary.html' %}
{% endblock %}

{% block progress %}
    {% include 'dashboard/offers/progress.html' with step=4 %}
{% endblock %}

{% block submittext %}{% trans "Save this offer" %}{% endblock %}

{% block extrascripts %}
    {{ block.super }}
    <script src="{{ STATIC_URL }}oscar/js/timepicker/jquery-ui-timepicker-addon.js" type="text/javascript"></script>
{% endblock %}
