{% extends "layout.html" %}

{% block title %}
{{ flatpage.title}} | {{ block.super }}
{% endblock %}

{% block headertext %}
{{ flatpage.title }}
{% endblock %}

{% block content %}
<article>{{ flatpage.content|linebreaks }}</article>
{% endblock %}
