{% extends "layout.html" %}
{% load currency_filters %}
{% load i18n %}

{% block title %}
{% trans 'Login or register' %} | {{ block.super }}
{% endblock %}

{% block breadcrumbs %}
<ul class="breadcrumb">
    <li>
        <a href="{% url promotions:home %}">{% trans 'Home' %}</a>
        <span class="divider">/</span>
    </li>
	<li class="active">{% trans 'Login or register' %}</li>
</ul>
{% endblock %}

{% block content %}

<div class="row-fluid">
    <div class="span6 login_form">
        <form id="login_form" action="{{ request.get_full_path }}" method="post" class="form-stacked" >
            <h2>{% trans 'Log In' %}</h2>
            {% csrf_token %}
            {% include "partials/form_fields.html" with form=login_form %}
			<p><a href="{% url password-reset %}">{% trans "I've forgotten my password" %}</a></p>
            <button name="login_submit" type="submit" value="Log In" class="btn btn-large btn-primary">{% trans 'Log In' %}</button>
        </form>
    </div>
    <div class="span6 register_form">
        <form id="register_form" action="{{ request.get_full_path }}" method="post" class="form-stacked">
            <h2>{% trans 'Register' %}</h2>
            {% csrf_token %}
            {% include "partials/form_fields.html" with form=registration_form %}
            <button name="registration_submit" type="submit" value="Register" class="btn btn-large btn-primary js-disable-on-click" data-loading-text="{%trans 'Registering...' %}">{% trans 'Register' %}</button>
        </form>
    </div>
</div>    

{% endblock content %}
