_gaq.push(['_addTrans',
    '{{ order.number|escapejs }}',
    '{{ shop_name|escapejs }}',
    '{{ order.total_incl_tax|escapejs }}',
    '{{ order.total_tax|escapejs }}',
    '{{ order.shipping_incl_tax|escapejs }}',
    '{{ order.shipping_address.line4|escapejs }}',
    '{{ order.shipping_address.state|escapejs }}',
    '{{ order.shipping_address.country.name|escapejs }}'
]);
{% for line in order.lines.all %}
    _gaq.push(['_addItem',
        '{{ order.number }}',
        '{{ line.partner_sku|escapejs }}',
        '{{ line.title|escapejs }}',
        '{{ line.category|escapejs }}',
        '{{ line.unit_price_incl_tax }}',
        '{{ line.quantity }}']);
{% endfor %}
_gaq.push(['_trackTrans']);

