{% extends "layout.html" %}
{% load currency_filters %}
{% load thumbnail %}
{% load i18n %}

{% block title %}
{% trans "Basket" %} | {{ block.super }}
{% endblock %}

{# Hide mini-basket so we don't have two baskets to keep in sync #}
{% block mini_basket %}{% endblock %}

{% block headertext %}
{% trans "Basket" %}
{% endblock %}

{% block content %}
    {# Use a partial template so that AJAX can be used to re-render basket #}
    {% include 'basket/partials/basket_content.html' %}
{% endblock content %}

{% block onbodyload %}
{# We pass in the URL to send AJAX requests to #}
var options = {
    'basketURL': '{% url basket:summary %}'
};
oscar.basket.init(options);
{% endblock %}
