{% load currency_filters %}
{% load basket_tags %}
{% load thumbnail %}
{% load i18n %}

<article class="well promotion_single">
    <div class="sub-header">
    	<h2>{{ promotion.name }}</h2>
    </div>
    <div class="row-fluid">
    	<div class="span3">
    		<div class="image_container"> 
				{% with image=product.primary_image %}
				{% thumbnail image.original "400x400" upscale=False as thumb %}
                    <a href="{{ product.get_absolute_url }}"><img class="thumbnail" src="{{ thumb.url }}" alt="{{ product.get_title }}"></a>
				{% endthumbnail %}
				{% endwith %}
    		</div>    
    	</div>
    	<div class="span9">
            <h3><a href="{{ product.get_absolute_url }}">{{ product.title }}</a></h3>
            <div class="product_price">
                {% include "catalogue/partials/stock_record.html" %}
            </div>
            {{ promotion.description|safe }}
    	</div>
    </div>
</article>
