{% extends 'dashboard/layout.html' %}
{% load currency_filters %}
{% load i18n %}

{% block body_class %}create-page pages{% endblock %}
{% block title %}
{{ title }} | {{ block.super }}
{% endblock %}

{% block breadcrumbs %}
<ul class="breadcrumb">
    <li>
        <a href="{% url dashboard:index %}">{% trans "Dashboard" %}</a>
        <span class="divider">/</span>
    </li>
    <li>
        <a href="{% url dashboard:page-list %}">{% trans "Pages" %}</a>
        <span class="divider">/</span>
    </li>
    <li class="active">{{ title }}</li>
</ul>
{% endblock %}

{% block headertext %}
{{ title }}
{% endblock %}

{% block dashboard_content %}
<div class="table-header">
    <h2>{{ title }}</h2>
</div>

<form action="." method="post" class="well form-stacked wysiwyg" enctype="multipart/form-data">
	{% csrf_token %}
    {% include 'partials/form.html' %}
</form>

{% endblock dashboard_content %}
